/* eslint-disable @next/next/no-img-element */
"use client";

import Image from "next/image";
import pen from "./icons/pen.svg";
import close from "./icons/close.svg";
import close_white from "./icons/close-white.svg";
import { authInstanse } from "@/shared/config/apiConfig";
import { useRouter } from "next/navigation";
import { useSession } from "next-auth/react";
import { useState } from "react";
import { AxiosError } from "axios";
import Loader from "@/shared/ui/Loader/Loader";
import profile from "./icons/profile.png";

interface IProfileAvatarProps {
  img: string;
}

const ProfileAvatar: React.FC<IProfileAvatarProps> = ({
  img,
}: IProfileAvatarProps) => {
  const [modal, setModal] = useState<boolean>(false);
  const [display_image, setDisplayImage] = useState<File | string>(img);
  const [isDeleting, setIsDeleting] = useState<boolean>(false);
  const [message, setMessage] = useState<boolean>(false);

  const [success, setSuccess] = useState<string>("");
  const [loader, setLoader] = useState<boolean>(false);
  const [error, setError] = useState<string>("");

  const session = useSession();
  const router = useRouter();
  const def = profile;
  const handleChange: React.ChangeEventHandler<HTMLInputElement> = (e) => {
    if (e.target.files) {
      setDisplayImage(e.target.files[0]);
    }
  };

  const changeImage = async () => {
    const formData = new FormData();

    if (session.status === "unauthenticated") return;

    if (typeof display_image === typeof "string" || display_image === img)
      return;

    formData.append("image", display_image);

    try {
      setLoader(true);
      const res = await authInstanse(
        session.data?.access_token as string
      ).patch("/users/update_image/", formData);

      setError("");
      setSuccess("Фото профиля обновлено");
      setMessage(true);
      router.refresh();

      setTimeout(() => {
        setMessage(false);
      }, 3000);
    } catch (error: unknown) {
      if (error instanceof AxiosError) {
        setSuccess("");
        setError(error.message);
        setMessage(true);
        setTimeout(() => {
          setMessage(false);
        }, 3000);
      }
    } finally {
      setLoader(false);
    }
  };

  const returnDefaultImage = async () => {
    if (session.status === "unauthenticated") return;

    try {
      setLoader(true);
      const res = await authInstanse(
        session.data?.access_token as string
      ).patch("/users/delete_image/", {});

      setError("");
      setSuccess("Фото профиля удалено");
      setMessage(true);
      router.refresh();

      setTimeout(() => {
        setMessage(false);
      }, 3000);
    } catch (error: unknown) {
      if (error instanceof AxiosError) {
        setSuccess("");
        setError(error.message);
        setMessage(true);
        setTimeout(() => {
          setMessage(false);
        }, 3000);
      }
    } finally {
      setLoader(false);
    }
  };

  const imageIsString =
    typeof display_image === "string"
      ? display_image
      : typeof display_image === "undefined"
      ? ""
      : URL.createObjectURL(display_image as File);
  return (
    <div className="mb-[25px] relative w-[135px] h-[135px]">
      <img
        className="w-full h-full rounded-lg object-cover"
        src={img}
        alt="User Image"
      />
      <button
        onClick={() => setModal(true)}
        className="absolute bottom-0 right-0 w-[50px] h-[50px] flex items-center justify-center shadow-sm bg-white rounded-lg cursor-pointer"
      >
        <Image src={pen} alt="Pen Icon" width={22} height={22} />
      </button>

      {modal && (
        <div
          onClick={() => setModal(false)}
          className="w-full h-full fixed top-0 left-0 flex items-center justify-center bg-black"
        >
          <div
            onClick={(e) => e.stopPropagation()}
            className="relative max-w-[400px] p-6 flex flex-col items-center bg-white rounded-sm shadow-sm"
          >
            <div>
              <div className="flex items-center justify-between">
                <h4 className="text-[14px] font-semibold leading-6 ">
                  Фото профиля
                </h4>
                <button
                  className="w-6 h-6 flex items-center justify-center border border-white rounded-lg"
                  onClick={() => setModal(false)}
                >
                  <Image src={close} alt="Close Icon" />
                </button>
              </div>
              <p className="w-[90%] text-[14px] leading-5 text-gray-400">
                По фото профиля другие люди смогут вас узнавать, а вам будет
                проще определять, в какой аккаунт вы вошли.
              </p>
            </div>

            <img
              className="my-6 w-[130px] h-[130px] rounded-lg object-cover"
              src={imageIsString}
              alt="User image"
            />
            <div className="flex items-center gap-2">
              {typeof def === 'string' && img === def && display_image === def ? (
                <>
                  <label
                    className="min-w-[110px] py-2 px-4 mt-6 flex items-center justify-center text-[14px] font-semibold leading-5 rounded-sm cursor-pointer"
                    htmlFor="change-image"
                  >
                    Добавить фото профиля
                  </label>
                  <input
                    onChange={handleChange}
                    id="change-image"
                    type="file"
                  />
                </>
              ) : isDeleting ? (
                <>
                  <button
                    onClick={() => setIsDeleting(false)}
                    className="bg-white text-black"
                  >
                    Отмена
                  </button>
                  <button
                    onClick={returnDefaultImage}
                    disabled={loader}
                    className="bg-blue text-white"
                  >
                    {loader ? <Loader /> : "Удалить"}
                  </button>
                </>
              ) : img === display_image || success !== "" ? (
                <>
                  <button
                    onClick={() => setIsDeleting(true)}
                    className="bg-white text-black"
                  >
                    Удалить
                  </button>
                  <label className="bg-blue text-white" htmlFor="change-image">
                    Сменить
                  </label>
                  <input
                    onChange={handleChange}
                    id="change-image"
                    type="file"
                  />
                </>
              ) : (
                <>
                  <button
                    onClick={() => setDisplayImage(img)}
                    className="bg-white text-black"
                  >
                    Назад
                  </button>
                  <button
                    disabled={loader}
                    onClick={changeImage}
                    className="bg-blue text-white"
                  >
                    {loader ? <Loader /> : "Сохранить"}
                  </button>
                </>
              )}
            </div>

            {message && (
              <div className="absolute bottom-[32px] p-2 w-[302px] flex items-center justify-between rounded-sm bg-black text-[14px] font-semibold leading-5 text-white">
                <p>
                  {success} {error}
                </p>
                <button className="text-0" onClick={() => setMessage(false)}>
                  <Image src={close_white} alt="Close Icon White" />
                </button>
              </div>
            )}
          </div>
        </div>
      )}
    </div>
  );
};

export default ProfileAvatar;
