"use client";

import { useEffect, useState } from "react";
import { apiInstance } from "@/shared/config/apiConfig";
import { useRouter } from "@/shared/config/navigation";
import { AxiosError } from "axios";
import Loader from "@/shared/ui/Loader/Loader";
import { cn } from "@/lib/utils";
import { useTranslations } from "next-intl";

interface IConfirmEmailFormProps {
  email: string;
}

const ConfirmEmailForm: React.FC<IConfirmEmailFormProps> = ({
  email,
}: IConfirmEmailFormProps) => {
  const t = useTranslations("confirmEmail");
  const router = useRouter();
  const [otp, setOtp] = useState(new Array(6).fill(""));
  const [seconds, setSeconds] = useState<number>(0);
  const [minutes, setMinutes] = useState<number>(1);
  const [error, setError] = useState<string>("");
  const [loader, setLoader] = useState<boolean>(false);

  const handleChange = (e: any, index: number) => {
    if (isNaN(+e.target.value)) return false;

    setOtp([...otp.map((data, i) => (i === index ? e.target.value : data))]);

    if (e.target.value && e.target.nextSibling) {
      e.target.nextSibling.focus();
    } else if (!e.target.value && e.target.previousSibling) {
      e.target.previousSibling.focus();
    }
  };
  const handleSubmit: React.MouseEventHandler<HTMLFormElement> = async (e) => {
    e.preventDefault();

    const codeString = otp.join("");

    try {
      setLoader(true);

      const response = await apiInstance.post("/auth/confirm_user/", {
        code: codeString,
      });
      console.log(response);
      if (response.status === 200 || response.status === 201) {
        router.push("/sign-in");
      }
    } catch (error: unknown) {
      if (error instanceof AxiosError) {
        if ([400, 404].includes(error.response?.status as number)) {
          setError("Неверный код подтверждения");
        } else {
          setError("Ошибка на стороне сервера");
        }
      } else {
        setError("Произошла непредвиденная ошибка");
      }
    } finally {
      setLoader(false);
    }
  };

  const handleClick = async () => {
    try {
      const data = {
        email,
      };
      const response = await apiInstance.post("/auth/send_mailcode/", data);

      if ([200, 201].includes(response.status)) {
        setMinutes(1);
      }
    } catch (error) {
      setError(
        "Проблема на стороне сервера или вы достигли максимальное количество попыток"
      );
    }
  };

  useEffect(() => {
    if (minutes === 0 && seconds === 0) return;

    const timer = setInterval(() => {
      if (seconds === 0) {
        setMinutes((prev) => Math.max(0, prev - 1));
        setSeconds(59);
      } else {
        setSeconds((prev) => prev - 1);
      }
    }, 1000);

    return () => clearInterval(timer);
  }, [minutes, seconds]);

  return (
    <form
      onSubmit={handleSubmit}
      className="w-[360px] flex flex-col items-center sm:w-full"
    >
      <div className="max-w-[360px] mb-[50px] flex flex-col items-center gap-[6px]">
        <label className="self-start text-sm leading-5 text-gray-500">
          {t("code")}
        </label>
        <div className="flex items-center gap-[6px] sm:grid sm:grid-cols-6">
          {otp.map((data, index) => (
            <input
              id={
                data && "border border-blue-500 rounded-sm shadow-sm bg-white"
              }
              key={index}
              onChange={(e) => handleChange(e, index)}
              value={data}
              maxLength={1}
              type="text"
              className="text-center p-2 max-w-[55px] h-[64px] flex items-center justify-center border border-gray-300 rounded-md shadow-sm bg-white text-[48px] font-medium leading-[60px] text-light-blue sm:w-full"
            />
          ))}
        </div>
        {error && <p className="leading-6 text-red-500">{error}</p>}
      </div>
      <button
        disabled={otp.join("").length === 6 ? false : true}
        className={cn(
          "bg-gray-300 text-white py-[10px] px-[18px] w-full rounded-md text-bold leading-6 shadow-md",
          {
            "bg-light-blue text-white": otp.join("").length === 6,
          }
        )}
        type="submit"
      >
        {loader ? <Loader /> : t("submitBtn")}
      </button>

      <p className="text-center my-8 leading-6 text-gray-500">
        {t("resendIn")}{" "}
        <span className="text-light-blue">
          0{minutes}:{seconds.toString().length === 1 ? `0${seconds}` : seconds}
        </span>
      </p>

      <button
        type="button"
        onClick={handleClick}
        disabled={minutes === 0 && seconds === 0 ? false : true}
        className={cn(
          "border border-gray-400 bg-white text-gray-300 py-[10px] px-[18px] w-full rounded-md text-bold leading-6 shadow-md",
          {
            "bg-light-blue text-white border-none":
              minutes === 0 && seconds === 0,
          }
        )}
      >
        {loader ? <Loader /> : t("resendBtn")}
      </button>
    </form>
  );
};

export default ConfirmEmailForm;
