import Image from "next/image";
import key from "./icons/key.svg";
import { useState } from "react";
import { apiInstance } from "@/shared/config/apiConfig";
import { ITokens } from "@/shared/types/token-type";
import { useRouter } from "@/shared/config/navigation";
import { AxiosError } from "axios";
import Loader from "@/shared/ui/Loader/Loader";
import { z } from "zod";
import { useForm } from "react-hook-form";
import { zodResolver } from "@hookform/resolvers/zod";
import alert from "../../icons/alert-circle.svg";
import { useTranslations } from "next-intl";

interface IConfirmCodeProps {
  setChangeForm: (boolean: boolean) => void;
}

const ConfirmCode: React.FC<IConfirmCodeProps> = ({
  setChangeForm,
}: IConfirmCodeProps) => {
  const [error, setError] = useState<string>("");
  const [loader, setLoader] = useState<boolean>(false);
  const router = useRouter();
  const t = useTranslations("confirmCodeForgot");

  const confirmCodeScheme = z.object({
    code: z.string().min(6, t("min")),
  });
  type FormFields = z.infer<typeof confirmCodeScheme>;

  const {
    register,
    handleSubmit,
    formState: { errors, isSubmitting },
  } = useForm<FormFields>({
    resolver: zodResolver(confirmCodeScheme),
  });
  const onSubmit = async (data: FormFields) => {
    try {
      setError("");
      setLoader(true);
      const res = await apiInstance.post<ITokens>(
        "/auth/confirm_password/",
        data
      );
      console.log(res.data);
      if (res.status === 200 || res.status === 201) {
        localStorage.setItem("transitional", JSON.stringify(res.data));
        router.push("/sign-in/reset-code");
      }
      setLoader(false);
    } catch (error: unknown) {
      if (error instanceof AxiosError) {
        if (error.response?.status === 400) {
          setError(t("incorrect"));
        } else {
          setError(t("serverError"));
        }
      } else {
        setError(t("errorOccured"));
      }
      setLoader(false);
    }
  };
  return (
    <div className="flex items-center flex-col gap-6">
      <div className="min-w-[60px] min-h-[60px] flex items-center justify-center border border-light-blue rounded-full">
        <Image src={key} alt="Key Icon" className="w-[24px] h-[24px]" />
      </div>
      <div className="auth-header">
        <h2 className="text-[24px] font-bold leading-8 text-gray-900 text-center">
          {t("enterCode")}
        </h2>
        <p className="leading-6 text-gray-500">{t("enterInfo")}</p>
      </div>

      <form
        onSubmit={handleSubmit(onSubmit)}
        className="w-[360px] flex flex-col gap-8"
      >
        <div>
          <label className="text-[14px] leading-5 text-gray-700">
            {t("code")}
          </label>
          <div
            className={`flex items-center${
              errors.code?.message && "border border-red-400"
            }`}
          >
            <input
              placeholder={t("code")}
              className="w-full text-[16px] leading-6 text-gray-900 px-[10px] py-[14px] border border-gray-300 rounded-lg shadow-sm bg-white"
              type="text"
              {...register("code", { required: true })}
            />
          </div>
          {errors?.code?.message && (
            <p className="flex items-center justify-between text-[14px] font-normal leading-5 text-red-500">
              {errors.code.message} <Image src={alert} alt="Alert Icon" />
            </p>
          )}
        </div>
        <button
          type="submit"
          className=" w-full h-[44px] rounded-md shadow-sm bg-light-blue font-bold leading-6 text-white"
        >
          {loader ? <Loader /> : t("getPassword")}
        </button>
        {error && <div className="text-red-500">{error}</div>}
        {errors.root && (
          <div className="text-red-500">{errors.root.message}</div>
        )}
      </form>
      <button
        onClick={() => setChangeForm(false)}
        className="text-light-blue leading-6"
      >
        {t("getCode")}
      </button>
    </div>
  );
};

export default ConfirmCode;
