import Image from "next/image";
import mail from "./icons/mail.svg";
import { useState } from "react";
import { apiInstance } from "@/shared/config/apiConfig";
import { AxiosError } from "axios";
import Loader from "@/shared/ui/Loader/Loader";
import { z } from "zod";
import { useForm } from "react-hook-form";
import { zodResolver } from "@hookform/resolvers/zod";
import alert from "../../icons/alert-circle.svg";
import { useTranslations } from "next-intl";

interface ISendEmailProps {
  setChangeForm: (boolean: boolean) => void;
}

const SendEmail: React.FC<ISendEmailProps> = ({
  setChangeForm,
}: ISendEmailProps) => {
  const [error, setError] = useState<string>("");
  const [loader, setLoader] = useState<boolean>(false);
  const t = useTranslations("forgotPasswordEmail");

  const sendEmailFormScheme = z.object({
    email: z.string().email(t("emailFormat")),
  });
  type FormFields = z.infer<typeof sendEmailFormScheme>;

  const {
    register,
    handleSubmit,
    formState: { errors, isSubmitting },
  } = useForm<FormFields>({
    resolver: zodResolver(sendEmailFormScheme),
  });

  const onSubmit = async (data: FormFields) => {
    try {
      setError("");
      setLoader(true);
      const res = await apiInstance.post("/auth/send_mailcode/", data);

      if ([200, 201].includes(res.status)) {
        console.log(res.data);
        setChangeForm(true);
      }
    } catch (error: unknown) {
      if (error instanceof AxiosError) {
        console.log(error);
        if (error.response?.status === 400) {
          setError(t("userNotFound"));
        } else {
          setError(t("serverError"));
        }
      } else {
        setError(t("errorOccured"));
      }
    } finally {
      setLoader(false);
    }
  };
  return (
    <div className="flex items-center flex-col gap-6">
      <div className="min-w-[60px] min-h-[60px] flex items-center justify-center border border-light-blue rounded-full">
        <Image src={mail} alt="Key Icon" className="w-[24px] h-[24px]" />
      </div>
      <div className="mb-2 flex flex-col items-center gap-2 text-center">
        <h2 className="text-[24px] font-bold leading-8 text-gray-900">
          {t("enter")}
        </h2>
        <p className="leading-6 text-gray-500">{t("desc")}</p>
      </div>

      <form
        onSubmit={handleSubmit(onSubmit)}
        className="w-[360px] flex flex-col gap-8"
      >
        <div>
          <label className="text-[14px] leading-5 text-gray-700">Email</label>
          <div
            className={`flex items-center${
              errors.email?.message && "border border-red-400"
            }`}
          >
            <input
              placeholder="Email"
              className="w-full text-[16px] leading-6 text-gray-900 px-[10px] py-[14px] border border-gray-300 rounded-lg shadow-sm bg-white"
              type="text"
              {...register("email", { required: true })}
            />
          </div>
          {errors?.email?.message && (
            <p className="flex items-center justify-between text-[14px] font-normal leading-5 text-red-500">
              {errors.email.message} <Image src={alert} alt="Alert Icon" />
            </p>
          )}
        </div>
        <button
          type="submit"
          className="w-full h-[44px] rounded-md shadow-sm bg-light-blue font-bold leading-6 text-white"
        >
          {loader ? <Loader /> : t("sendCode")}
        </button>
      </form>
      {error && <div className="text-red-500">{error}</div>}
      {errors.root && <div className="text-red-500">{errors.root.message}</div>}
    </div>
  );
};

export default SendEmail;
