"use client";

import Image from "next/image";
import pen from "./icons/pen.svg";
import { useState } from "react";
import { apiInstance } from "@/shared/config/apiConfig";
import { AxiosError } from "axios";
import { useSession } from "next-auth/react";
import { useRouter } from "@/shared/config/navigation";
import Loader from "@/shared/ui/Loader/Loader";
import LogoutButton from "@/features/LogoutButton";
import { z } from "zod";
import { useForm } from "react-hook-form";
import { zodResolver } from "@hookform/resolvers/zod";
import alert from "./icons/alert-circle.svg";
import ChangePassword from "./ChangePassword/ChangePassword";

interface IProfileFormProps {
  id: number;
  email: string;
  first_name: string;
  last_name: string;
}

const ProfileForm: React.FC<IProfileFormProps> = ({
  id,
  email,
  first_name,
  last_name,
}: IProfileFormProps) => {
  const session = useSession();
  const router = useRouter();
  const [error, setError] = useState<string>("");
  const [loader, setLoader] = useState<boolean>(false);

  const [editFirstName, setEditFirstName] = useState<boolean>(true);
  const [editLastName, setEditLastName] = useState<boolean>(true);

  const [firstName, setFirstName] = useState<string>(first_name);
  const [lastName, setLastName] = useState<string>(last_name);

  const [openPopup, setOpenPopup] = useState<boolean>(false);

  const thereAreChanges = () => {
    if (firstName !== first_name || lastName !== last_name) return false;

    return true;
  };

  const updateProfileScheme = z.object({
    firstName: z.string().min(2, "Минимум 2 символа"),
    lastName: z.string().min(2, "Минимум 2 символа"),
  });

  type FormFields = z.infer<typeof updateProfileScheme>;

  const {
    register,
    handleSubmit,
    formState: { errors },
  } = useForm<FormFields>({
    resolver: zodResolver(updateProfileScheme),
  });

  const onSubmit = async (data: FormFields) => {
    const Authorization = `Bearer ${session.data?.access_token}`;
    const config = {
      headers: {
        Authorization,
      },
    };

    try {
      setLoader(true);
      const res = await apiInstance.patch("/users/profile/", data, config);
      if ([200, 201].includes(res.status)) {
        router.refresh();
      }
    } catch (error: unknown) {
      if (error instanceof AxiosError) {
        if (error.response?.status === 400) {
          setError("Были введены неккоректные данные");
        } else {
          setError("Ошибка на стороне сервера");
        }
      } else {
        setError("Возникла непредвиденная ошибка");
      }
    } finally {
      setLoader(false);
    }
  };
  return (
    <>
      <form
        onSubmit={handleSubmit(onSubmit)}
        className="flex flex-col gap-[25px]"
      >
        <div className="flex flex-col gap-[10px]">
          <label className="text-[18px] leading-6 text-gray-500">Имя</label>
          <div
            className={`flex items-center gap-4 ${
              errors.firstName?.message && "border border-red-400"
            }`}
          >
            <input
              value={firstName}
              {...register("firstName", { required: true })}
              type="text"
              className="w-full max-w-[957px] p-4 border border-gray-400 rounded-md mr-2 text-[18px] leading-6 text-black"
            />
            <button
              type="button"
              onClick={() => setEditFirstName((prev) => !prev)}
            >
              <Image className="w-[22px] h-[22px]" src={pen} alt="Pen Icon" />
            </button>
          </div>
          {errors?.firstName?.message && (
            <p className="flex items-center justify-between text-[14px] font-normal leading-5 text-red-500">
              {errors.firstName.message} <Image src={alert} alt="Alert Icon" />
            </p>
          )}
        </div>

        <div className="flex flex-col gap-[10px]">
          <label className="text-[18px] leading-6 text-gray-500">Фамилия</label>
          <div
            className={`flex items-center gap-4 ${
              errors.firstName?.message && "border border-red-400"
            }`}
          >
            <input
              value={lastName}
              {...register("lastName", { required: true })}
              type="text"
              className="w-full max-w-[957px] p-4 border border-gray-400 rounded-md mr-2 text-[18px] leading-6 text-black"
            />
            <button
              type="button"
              onClick={() => setEditLastName((prev) => !prev)}
            >
              <Image src={pen} alt="Pen Icon" className="w-[22px] h-[22px]" />
            </button>
          </div>
          {errors?.lastName?.message && (
            <p className="flex items-center justify-between text-[14px] font-normal leading-5 text-red-500">
              {errors.lastName.message} <Image src={alert} alt="Alert Icon" />
            </p>
          )}
        </div>

        <div className="flex flex-col gap-[10px]">
          <label className="text-[18px] leading-6 text-gray-500">Email</label>
          <div className="flex items-center gap-4">
            <input
              value={email}
              disabled
              type="text"
              className="w-full max-w-[957px] p-4 border border-gray-400 rounded-md mr-2 text-[18px] leading-6 text-black"
            />
          </div>
        </div>

        <div className="flex flex-col gap-[10px]">
          <label className="text-[18px] leading-6 text-gray-500">Пароль</label>
          <div className="flex items-center gap-4">
            <input
              value={"*****************************"}
              disabled={editLastName}
              type="password"
              className="w-full max-w-[957px] p-4 border border-gray-400 rounded-md mr-2 text-[18px] leading-6 text-black"
            />
            <button onClick={() => setOpenPopup(true)} type="button">
              <Image src={pen} alt="Pen Icon" className="w-[22px] h-[22px]" />
            </button>
          </div>
        </div>
        {error ? <p>{error}</p> : null}

        <button
          disabled={thereAreChanges()}
          type="submit"
          className={`mt-[50px] w-fit p-[10px] rounded-lg bg-gray-400 cursor-auto font-bold leading-7 text-gray-200${
            thereAreChanges() ? "" : "bg-light-blue cursor-pointer"
          }`}
        >
          {loader ? <Loader /> : "Сохранить изменения"}
        </button>
        <LogoutButton className="lg:hidden sm:block" />
      </form>
      {openPopup && <ChangePassword closeWindow={setOpenPopup} />}
    </>
  );
};

export default ProfileForm;
